## Supported models

The table below lists the models that are guaranteed to be exportable to other backends.

| Model                       | Codebase         | TorchScript | OnnxRuntime | TensorRT | ncnn | PPLNN | OpenVINO | Ascend | RKNN |                                          Model config                                           |
| :-------------------------- | :--------------- | :---------: | :---------: | :------: | :--: | :---: | :------: | :----: | :--: | :---------------------------------------------------------------------------------------------: |
| RetinaNet                   | MMDetection      |      Y      |      Y      |    Y     |  Y   |   Y   |    Y     |   Y    |  Y   |        [config](https://github.com/open-mmlab/mmdetection/tree/master/configs/retinanet)        |
| Faster R-CNN                | MMDetection      |      Y      |      Y      |    Y     |  Y   |   Y   |    Y     |   Y    |  N   |       [config](https://github.com/open-mmlab/mmdetection/tree/master/configs/faster_rcnn)       |
| YOLOv3                      | MMDetection      |      Y      |      Y      |    Y     |  Y   |   N   |    Y     |   Y    |  Y   |          [config](https://github.com/open-mmlab/mmdetection/tree/master/configs/yolo)           |
| YOLOX                       | MMDetection      |      Y      |      Y      |    Y     |  Y   |   N   |    Y     |   N    |  Y   |          [config](https://github.com/open-mmlab/mmdetection/tree/master/configs/yolox)          |
| FCOS                        | MMDetection      |      Y      |      Y      |    Y     |  Y   |   N   |    Y     |   N    |  N   |          [config](https://github.com/open-mmlab/mmdetection/tree/master/configs/fcos)           |
| FSAF                        | MMDetection      |      Y      |      Y      |    Y     |  Y   |   Y   |    Y     |   N    |  Y   |          [config](https://github.com/open-mmlab/mmdetection/tree/master/configs/fsaf)           |
| Mask R-CNN                  | MMDetection      |      Y      |      Y      |    Y     |  N   |   N   |    Y     |   N    |  N   |        [config](https://github.com/open-mmlab/mmdetection/tree/master/configs/mask_rcnn)        |
| SSD[\*](#note)              | MMDetection      |      Y      |      Y      |    Y     |  Y   |   N   |    Y     |   N    |  Y   |           [config](https://github.com/open-mmlab/mmdetection/tree/master/configs/ssd)           |
| FoveaBox                    | MMDetection      |      Y      |      Y      |    N     |  N   |   N   |    Y     |   N    |  N   |        [config](https://github.com/open-mmlab/mmdetection/tree/master/configs/foveabox)         |
| ATSS                        | MMDetection      |      N      |      Y      |    Y     |  N   |   N   |    Y     |   N    |  N   |          [config](https://github.com/open-mmlab/mmdetection/tree/master/configs/atss)           |
| GFL                         | MMDetection      |      N      |      Y      |    Y     |  N   |   ?   |    Y     |   N    |  N   |           [config](https://github.com/open-mmlab/mmdetection/tree/master/configs/gfl)           |
| Cascade R-CNN               | MMDetection      |      N      |      Y      |    Y     |  N   |   Y   |    Y     |   N    |  N   |      [config](https://github.com/open-mmlab/mmdetection/tree/master/configs/cascade_rcnn)       |
| Cascade Mask R-CNN          | MMDetection      |      N      |      Y      |    Y     |  N   |   N   |    Y     |   N    |  N   |      [config](https://github.com/open-mmlab/mmdetection/tree/master/configs/cascade_rcnn)       |
| ConvNeXt                    | MMDetection      |      N      |      Y      |    Y     |  N   |   N   |    Y     |   N    |  N   |        [config](https://github.com/open-mmlab/mmdetection/tree/master/configs/convnext)         |
| Swin Transformer[\*](#note) | MMDetection      |      N      |      Y      |    Y     |  N   |   N   |    N     |   N    |  N   |          [config](https://github.com/open-mmlab/mmdetection/tree/master/configs/swin)           |
| VFNet                       | MMDetection      |      N      |      N      |    N     |  N   |   N   |    Y     |   N    |  N   |          [config](https://github.com/open-mmlab/mmdetection/tree/master/configs/vfnet)          |
| RepPoints                   | MMDetection      |      N      |      N      |    Y     |  N   |   ?   |    Y     |   N    |  N   |        [config](https://github.com/open-mmlab/mmdetection/tree/master/configs/reppoints)        |
| DETR                        | MMDetection      |      N      |      Y      |    Y     |  N   |   ?   |    N     |   N    |  N   |          [config](https://github.com/open-mmlab/mmdetection/tree/master/configs/detr)           |
| ResNet                      | MMClassification |      Y      |      Y      |    Y     |  Y   |   Y   |    Y     |   Y    |  Y   |       [config](https://github.com/open-mmlab/mmclassification/tree/master/configs/resnet)       |
| ResNeXt                     | MMClassification |      Y      |      Y      |    Y     |  Y   |   Y   |    Y     |   Y    |  Y   |      [config](https://github.com/open-mmlab/mmclassification/tree/master/configs/resnext)       |
| SE-ResNet                   | MMClassification |      Y      |      Y      |    Y     |  Y   |   Y   |    Y     |   Y    |  Y   |      [config](https://github.com/open-mmlab/mmclassification/tree/master/configs/seresnet)      |
| MobileNetV2                 | MMClassification |      Y      |      Y      |    Y     |  Y   |   Y   |    Y     |   Y    |  Y   |    [config](https://github.com/open-mmlab/mmclassification/tree/master/configs/mobilenet_v2)    |
| ShuffleNetV1                | MMClassification |      Y      |      Y      |    Y     |  Y   |   Y   |    Y     |   Y    |  Y   |   [config](https://github.com/open-mmlab/mmclassification/tree/master/configs/shufflenet_v1)    |
| ShuffleNetV2                | MMClassification |      Y      |      Y      |    Y     |  Y   |   Y   |    Y     |   Y    |  Y   |   [config](https://github.com/open-mmlab/mmclassification/tree/master/configs/shufflenet_v2)    |
| VisionTransformer           | MMClassification |      Y      |      Y      |    Y     |  Y   |   ?   |    Y     |   Y    |  N   | [config](https://github.com/open-mmlab/mmclassification/tree/master/configs/vision_transformer) |
| SwinTransformer             | MMClassification |      Y      |      Y      |    Y     |  N   |   ?   |    N     |   ?    |  N   |  [config](https://github.com/open-mmlab/mmclassification/tree/master/configs/swin_transformer)  |
| FCN                         | MMSegmentation   |      Y      |      Y      |    Y     |  Y   |   Y   |    Y     |   Y    |  Y   |         [config](https://github.com/open-mmlab/mmsegmentation/tree/master/configs/fcn)          |
| PSPNet[\*static](#note)     | MMSegmentation   |      Y      |      Y      |    Y     |  Y   |   Y   |    Y     |   Y    |  Y   |        [config](https://github.com/open-mmlab/mmsegmentation/tree/master/configs/pspnet)        |
| DeepLabV3                   | MMSegmentation   |      Y      |      Y      |    Y     |  Y   |   Y   |    Y     |   Y    |  N   |      [config](https://github.com/open-mmlab/mmsegmentation/tree/master/configs/deeplabv3)       |
| DeepLabV3+                  | MMSegmentation   |      Y      |      Y      |    Y     |  Y   |   Y   |    Y     |   Y    |  N   |    [config](https://github.com/open-mmlab/mmsegmentation/tree/master/configs/deeplabv3plus)     |
| Fast-SCNN[\*static](#note)  | MMSegmentation   |      Y      |      Y      |    Y     |  N   |   Y   |    Y     |   N    |  Y   |       [config](https://github.com/open-mmlab/mmsegmentation/tree/master/configs/fastscnn)       |
| UNet                        | MMSegmentation   |      Y      |      Y      |    Y     |  Y   |   Y   |    Y     |   Y    |  Y   |         [config](https://github.com/open-mmlab/mmsegmentation/tree/master/configs/unet)         |
| ANN[\*](#note)              | MMSegmentation   |      Y      |      Y      |    Y     |  N   |   N   |    N     |   N    |  N   |         [config](https://github.com/open-mmlab/mmsegmentation/tree/master/configs/ann)          |
| APCNet                      | MMSegmentation   |      Y      |      Y      |    Y     |  Y   |   N   |    N     |   N    |  Y   |        [config](https://github.com/open-mmlab/mmsegmentation/tree/master/configs/apcnet)        |
| BiSeNetV1                   | MMSegmentation   |      Y      |      Y      |    Y     |  Y   |   N   |    Y     |   N    |  Y   |      [config](https://github.com/open-mmlab/mmsegmentation/tree/master/configs/bisenetv1)       |
| BiSeNetV2                   | MMSegmentation   |      Y      |      Y      |    Y     |  Y   |   N   |    Y     |   N    |  N   |      [config](https://github.com/open-mmlab/mmsegmentation/tree/master/configs/bisenetv2)       |
| CGNet                       | MMSegmentation   |      Y      |      Y      |    Y     |  Y   |   N   |    Y     |   N    |  Y   |        [config](https://github.com/open-mmlab/mmsegmentation/tree/master/configs/cgnet)         |
| DMNet                       | MMSegmentation   |      ?      |      Y      |    N     |  N   |   N   |    N     |   N    |  N   |        [config](https://github.com/open-mmlab/mmsegmentation/tree/master/configs/dmnet)         |
| DNLNet                      | MMSegmentation   |      ?      |      Y      |    Y     |  Y   |   N   |    Y     |   N    |  N   |        [config](https://github.com/open-mmlab/mmsegmentation/tree/master/configs/dnlnet)        |
| EMANet                      | MMSegmentation   |      Y      |      Y      |    Y     |  N   |   N   |    Y     |   N    |  N   |        [config](https://github.com/open-mmlab/mmsegmentation/tree/master/configs/emanet)        |
| EncNet                      | MMSegmentation   |      Y      |      Y      |    Y     |  N   |   N   |    Y     |   N    |  N   |        [config](https://github.com/open-mmlab/mmsegmentation/tree/master/configs/encnet)        |
| ERFNet                      | MMSegmentation   |      Y      |      Y      |    Y     |  Y   |   N   |    Y     |   N    |  Y   |        [config](https://github.com/open-mmlab/mmsegmentation/tree/master/configs/erfnet)        |
| FastFCN                     | MMSegmentation   |      Y      |      Y      |    Y     |  Y   |   N   |    Y     |   N    |  N   |       [config](https://github.com/open-mmlab/mmsegmentation/tree/master/configs/fastfcn)        |
| GCNet                       | MMSegmentation   |      Y      |      Y      |    Y     |  N   |   N   |    N     |   N    |  N   |        [config](https://github.com/open-mmlab/mmsegmentation/tree/master/configs/gcnet)         |
| ICNet[\*](#note)            | MMSegmentation   |      Y      |      Y      |    Y     |  N   |   N   |    Y     |   N    |  N   |        [config](https://github.com/open-mmlab/mmsegmentation/tree/master/configs/icnet)         |
| ISANet[\*static](#note)     | MMSegmentation   |      N      |      Y      |    Y     |  N   |   N   |    Y     |   N    |  Y   |        [config](https://github.com/open-mmlab/mmsegmentation/tree/master/configs/isanet)        |
| NonLocal Net                | MMSegmentation   |      ?      |      Y      |    Y     |  Y   |   N   |    Y     |   N    |  N   |     [config](https://github.com/open-mmlab/mmsegmentation/tree/master/configs/nonlocal_net)     |
| OCRNet                      | MMSegmentation   |      ?      |      Y      |    Y     |  Y   |   N   |    Y     |   N    |  Y   |        [config](https://github.com/open-mmlab/mmsegmentation/tree/master/configs/ocrnet)        |
| PointRend                   | MMSegmentation   |      Y      |      Y      |    Y     |  N   |   N   |    Y     |   N    |  N   |      [config](https://github.com/open-mmlab/mmsegmentation/tree/master/configs/point_rend)      |
| Semantic FPN                | MMSegmentation   |      Y      |      Y      |    Y     |  Y   |   N   |    Y     |   N    |  Y   |       [config](https://github.com/open-mmlab/mmsegmentation/tree/master/configs/sem_fpn)        |
| STDC                        | MMSegmentation   |      Y      |      Y      |    Y     |  Y   |   N   |    Y     |   N    |  Y   |         [config](https://github.com/open-mmlab/mmsegmentation/tree/master/configs/stdc)         |
| UPerNet[\*](#note)          | MMSegmentation   |      ?      |      Y      |    Y     |  N   |   N   |    N     |   N    |  Y   |       [config](https://github.com/open-mmlab/mmsegmentation/tree/master/configs/upernet)        |
| DANet                       | MMSegmentation   |      ?      |      Y      |    Y     |  N   |   N   |    N     |   N    |  N   |        [config](https://github.com/open-mmlab/mmsegmentation/tree/master/configs/danet)         |
| Segmenter[\*static](#note)  | MMSegmentation   |      Y      |      Y      |    Y     |  Y   |   N   |    Y     |   N    |  N   |      [config](https://github.com/open-mmlab/mmsegmentation/tree/master/configs/segmenter)       |
| SRCNN                       | MMEditing        |      Y      |      Y      |    Y     |  Y   |   Y   |    Y     |   N    |  N   |      [config](https://github.com/open-mmlab/mmediting/tree/master/configs/restorers/srcnn)      |
| ESRGAN                      | MMEditing        |      Y      |      Y      |    Y     |  Y   |   Y   |    Y     |   N    |  N   |     [config](https://github.com/open-mmlab/mmediting/tree/master/configs/restorers/esrgan)      |
| SRGAN                       | MMEditing        |      Y      |      Y      |    Y     |  Y   |   Y   |    Y     |   N    |  N   | [config](https://github.com/open-mmlab/mmediting/tree/master/configs/restorers/srresnet_srgan)  |
| SRResNet                    | MMEditing        |      Y      |      Y      |    Y     |  Y   |   Y   |    Y     |   N    |  N   | [config](https://github.com/open-mmlab/mmediting/tree/master/configs/restorers/srresnet_srgan)  |
| Real-ESRGAN                 | MMEditing        |      Y      |      Y      |    Y     |  Y   |   Y   |    Y     |   N    |  N   |   [config](https://github.com/open-mmlab/mmediting/tree/master/configs/restorers/real_esrgan)   |
| EDSR                        | MMEditing        |      Y      |      Y      |    Y     |  Y   |   N   |    Y     |   N    |  N   |      [config](https://github.com/open-mmlab/mmediting/tree/master/configs/restorers/edsr)       |
| RDN                         | MMEditing        |      Y      |      Y      |    Y     |  Y   |   Y   |    Y     |   N    |  N   |       [config](https://github.com/open-mmlab/mmediting/tree/master/configs/restorers/rdn)       |
| DBNet                       | MMOCR            |      Y      |      Y      |    Y     |  Y   |   Y   |    Y     |   Y    |  N   |          [config](https://github.com/open-mmlab/mmocr/tree/main/configs/textdet/dbnet)          |
| PANet                       | MMOCR            |      Y      |      Y      |    Y     |  Y   |   ?   |    Y     |   Y    |  N   |          [config](https://github.com/open-mmlab/mmocr/tree/main/configs/textdet/panet)          |
| PSENet                      | MMOCR            |      Y      |      Y      |    Y     |  Y   |   ?   |    Y     |   Y    |  N   |         [config](https://github.com/open-mmlab/mmocr/tree/main/configs/textdet/psenet)          |
| CRNN                        | MMOCR            |      Y      |      Y      |    Y     |  Y   |   Y   |    N     |   N    |  N   |         [config](https://github.com/open-mmlab/mmocr/tree/main/configs/textrecog/crnn)          |
| SAR                         | MMOCR            |      N      |      Y      |    N     |  N   |   N   |    N     |   N    |  N   |          [config](https://github.com/open-mmlab/mmocr/tree/main/configs/textrecog/sar)          |
| SATRN                       | MMOCR            |      Y      |      Y      |    Y     |  N   |   N   |    N     |   N    |  N   |         [config](https://github.com/open-mmlab/mmocr/tree/main/configs/textrecog/satrn)         |
| HRNet                       | MMPose           |      N      |      Y      |    Y     |  Y   |   N   |    Y     |   N    |  N   |     [config](https://mmpose.readthedocs.io/en/latest/papers/backbones.html#hrnet-cvpr-2019)     |
| MSPN                        | MMPose           |      N      |      Y      |    Y     |  Y   |   N   |    Y     |   N    |  N   |     [config](https://mmpose.readthedocs.io/en/latest/papers/backbones.html#mspn-arxiv-2019)     |
| LiteHRNet                   | MMPose           |      N      |      Y      |    Y     |  N   |   N   |    Y     |   N    |  N   |   [config](https://mmpose.readthedocs.io/en/latest/papers/backbones.html#litehrnet-cvpr-2021)   |
| Hourglass                   | MMPose           |      N      |      Y      |    Y     |  Y   |   N   |    Y     |   N    |  N   |   [config](https://mmpose.readthedocs.io/en/latest/papers/backbones.html#hourglass-eccv-2016)   |
| ViPNAS                      | MMPose           |      ?      |      ?      |    ?     |  Y   |   ?   |    ?     |   ?    |  ?   |   [config](https://mmpose.readthedocs.io/zh_CN/latest/papers/backbones.html#vipnas-cvpr-2021)   |
| PointPillars                | MMDetection3d    |      ?      |      Y      |    Y     |  N   |   N   |    Y     |   N    |  N   |     [config](https://github.com/open-mmlab/mmdetection3d/blob/master/configs/pointpillars)      |
| CenterPoint (pillar)        | MMDetection3d    |      ?      |      Y      |    Y     |  N   |   N   |    Y     |   N    |  N   |      [config](https://github.com/open-mmlab/mmdetection3d/blob/master/configs/centerpoint)      |
| Fcos3d                      | MMDetection3d    |      ?      |      Y      |    Y     |  N   |   N   |    N     |   N    |  N   |        [config](https://github.com/open-mmlab/mmdetection3d/blob/master/configs/fcos3d)         |
| RotatedRetinaNet            | RotatedDetection |      N      |      Y      |    Y     |  N   |   N   |    N     |   N    |  N   | [config](https://github.com/open-mmlab/mmrotate/blob/main/configs/rotated_retinanet/README.md)  |
| Oriented RCNN               | RotatedDetection |      N      |      Y      |    Y     |  N   |   N   |    N     |   N    |  N   |   [config](https://github.com/open-mmlab/mmrotate/blob/main/configs/oriented_rcnn/README.md)    |
| Gliding Vertex              | RotatedDetection |      N      |      N      |    Y     |  N   |   N   |    N     |   N    |  N   |   [config](https://github.com/open-mmlab/mmrotate/blob/main/configs/gliding_vertex/README.md)   |
| TSN                         | MMAction2        |      N      |      Y      |    Y     |  N   |   N   |    N     |   N    |  N   |      [config](https://github.com/open-mmlab/mmaction2/tree/master/configs/recognition/tsn)      |
| SlowFast                    | MMAction2        |      N      |      Y      |    Y     |  N   |   N   |    N     |   N    |  N   |   [config](https://github.com/open-mmlab/mmaction2/tree/master/configs/recognition/slowfast)    |

### Note

- Tag:
  - static: This model only support static export. Please use `static` deploy config, just like $MMDEPLOY_DIR/configs/mmseg/segmentation_tensorrt_static-1024x2048.py.
- SSD: When you convert SSD model, you need to use min shape deploy config just like 300x300-512x512 rather than 320x320-1344x1344, for example $MMDEPLOY_DIR/configs/mmdet/detection/detection_tensorrt_dynamic-300x300-512x512.py.
- YOLOX: YOLOX with ncnn only supports static shape.
- Swin Transformer: For TensorRT, only version 8.4+ is supported.
- SAR: Chinese text recognition model is not supported as the protobuf size of ONNX is limited.
